@@ -20,5 +20,9 @@ function test_bluer_objects_ls() {
     [[ $? -ne 0 ]] && return 1
     bluer_ai_hr
 
-    bluer_objects_ls $abcli_path_bash/tests/
+    bluer_objects_ls cloud,objects --prefix 2025-09
+    [[ $? -ne 0 ]] && return 1
+    bluer_ai_hr
+
+    bluer_objects_ls local,objects --prefix 2025-09
 }
